@@ -1,6 +1,6 @@
 package B::Debugger;
 
-our $VERSION = '0.01_03';
+our $VERSION = '0.02';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -86,6 +86,12 @@ Planned:
 
 =head1 TODO
 
+See L<Od>, freeze and thaw the optree and debug within
+L<perl5db> in C<INIT>.
+
+Delay the C<CHECK> block for L<B> or run L<perl5db> at the
+C<CHECK> block.
+
 How to manage direct opidx access?
 
   Such as: Concise 10, list 5-10, up, sib
